#!/usr/bin/env python

"""
Moin wiki table serialiser.

Copyright (C) 2017, 2018, 2021, 2023 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from moinformat.serialisers.moin.moin import MoinSerialiser

class MoinTableSerialiser(MoinSerialiser):

    "Serialisation of the page."

    input_formats = ["table"]

    def init(self):
        self.first_cell = False
        self.first_row = False

    def table(self, table):
        self.first_row = True
        self.container(table)

    def table_cell(self, table_cell):
        if not self.first_cell:
            self.out(table_cell.leading)
            self.out("||")
        else:
            self.first_cell = False

        self.out(table_cell.padding)
        self.container(table_cell)

    def table_row(self, table_row):
        self.first_cell = True

        if not self.first_row:
            self.out(table_row.leading)
            self.out("==")
            self.out(table_row.padding)
        else:
            self.first_row = False

        self.container(table_row)
        self.out(table_row.trailing)

    def continuation(self, continuation):
        self.out(continuation.text)

serialiser = MoinTableSerialiser

# vim: tabstop=4 expandtab shiftwidth=4
